<?php
/** Santali (Santali)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Albinus
 * @author David Baskey
 * @author Ghonokuashabaskey
 * @author Joseph Mardy
 * @author Nipon087
 * @author Reedy
 * @author Rillke
 * @author Salvator
 * @author Samar88
 * @author Srabony90
 */

$messages = array(
# User preference toggles
'tog-underline' => 'Joṛaoko latarre dag udugoḱma:',
'tog-justify' => 'Olaḱ kạli mońjte sajao:',
'tog-hideminor' => 'Nitaḱ bodolaḱre huḍiṅ kạmi danaṅme',
'tog-hidepatrolled' => 'Joṛaoakanaḱko nãwã bodolaḱte danaṅkam',
'tog-newpageshidepatrolled' => 'Biḍạakanaḱ sakamko nãwã sakamreaḱ talikare danȧkam',
'tog-extendwatchlist' => 'Khạli nitoḱ bodolko do baṅ, joto bodolkodo ńeloḱ tạlikare phaylaomẽ.',
'tog-usenewrc' => 'Nahaḱ bodolakanaḱko ar nojor reaḱ pahaṭare bodolaḱko mit́são ńelńam',
'tog-numberheadings' => 'Mukhiạ kathako do actege piṛhipiṛhite sajaḱma',
'tog-showtoolbar' => 'Joṛaoakanaḱ ṭulbar udugoḱma',
'tog-editondblclick' => 'Bar dhao lin kate sakam torjomão reaḱ ạidari emogoḱma',
'tog-editsection' => '[Joṛao] Pahaṭako do joṛao hotete aćtege hoyoḱ lạgit aidạri em ocoḱma',
'tog-editsectiononrightclick' => 'Pahaṭa reaḱ pahaṭa guṭkathare jojom seć lin hotete <br /> pahaṭa sompadon lạgitte ektiạr em hoyoḱma (JavaScript)',
'tog-showtoc' => 'Ṭibilre menaḱako ńel ( sakamkore 3 khon jạti hedlayenko)',
'tog-rememberpassword' => 'Noa sendrare amaḱ boloḱ reaḱ katha (katha cạbi) disạimẽ (jạstite $1 {{PLURAL:$1din reaḱ din reaḱ}} lạgit)',
'tog-watchcreations' => 'Ińaḱ tear sakam ar rakaṕ páelko ińaḱ ńelogoḱ tạlikare ńeloḱ ma',
'tog-watchdefault' => 'Ińaḱ purạoakanaḱ sakam ar phayelko do ińaḱ ńeloḱ tạlikare joṛaoḱma',
'tog-watchmoves' => 'Ińaḱ ocoḱ sakam ar phayelko inyaḱ nojor sakamre joṛaḱma',
'tog-watchdeletion' => 'Sakamko tońgeyme Ińaḱ ńeloḱ tạlika khon get́ giḍikam',
'tog-minordefault' => 'Etohoṕre sanam joṛao purạoanaḱko do bekor unuduḱ lekate cinhạkma',
'tog-previewontop' => 'Joṛao bakso purạo lahare unuduḱ hoyoḱma',
'tog-previewonfirst' => 'Pạhil joṛao purạore unuduḱ hoyoḱma',
'tog-nocache' => 'Brajar sakam reaḱ kasiṅ bondoemẽ',
'tog-enotifwatchlistpages' => 'E-mailạńme one tinre in̕aḱ n̕eloḱ tạlika do bodolok',
'tog-enotifusertalkpages' => 'E-mailạn̕me one tinre in̕aḱ roṛaḱ laṛcaṛ sakam do bodoloḱa',
'tog-enotifminoredits' => 'E-mailạn̕me arhõ one tinre in̕aḱ sakamre huḍiń kạmi hoyoḱ',
'tog-enotifrevealaddr' => 'Dhạrwạk reaḱ sakamre ińaḱ e-mail ṭhikạna sodor hoyoḱma',
'tog-shownumberswatching' => 'Ńelok laṛcaṛkoaḱ songkha uduḱme',
'tog-oldsig' => 'Menaḱ signạtar',
'tog-fancysig' => 'Signạcar do wikiṭesk hisạbte moneyemẽ (jahan acte hoyoḱ joṛao bạgikate)',
'tog-uselivepreview' => 'Jewet́ ńeloḱ beoharme (JavaScript jaruṛ menaḱa)',
'tog-forceeditsummary' => 'Khạli sompadon guṭkatha em oktere iń baḍae ocoyiń hoyoḱma',
'tog-watchlisthideown' => 'Ńeloḱ talikare ińaḱ joṛao kamiko danaṅme',
'tog-watchlisthidebots' => 'Boṭreaḱ sompadon kạmiko do ńeloḱ tạlika khon danaṅmẽ',
'tog-watchlisthideminor' => 'Ńeloḱ tạlikare ińak huḍiṅ joṛao kạmiko danaṅme',
'tog-watchlisthideliu' => 'Ńeloḱ tạlikareaḱ ekaunṭ bolok beoharkoaḱ sompadon danaṅ hoyoḱma',
'tog-watchlisthideanons' => 'Ńeloḱ tạlikare baṅ ńutamanić beoharićaḱ sompadonko danaṅ hoyoḱma',
'tog-watchlisthidepatrolled' => 'Biḍạen sompadonko do ńeloḱ sakamre danaṅmẽ',
'tog-ccmeonemails' => 'E-mail reaḱ kopy kulạńme Eṭaḱ laṛcaṛko kulakome',
'tog-diffonly' => 'Farak reaḱ latar sakamre babotko baṅ udugoḱma',
'tog-showhiddencats' => 'Danaṅ rokom sokomko uduḱmẽ',
'tog-norollbackdiff' => 'rollback tayomte farak alom uduga',

'underline-always' => 'Sanam okte',
'underline-never' => 'Tis hõ ban̕',
'underline-default' => 'Browjarre cetlekate em hoy akana',

# Font style option in Special:Preferences
'editfont-style' => 'Sompadon ṭhại reaḱ fonṭ sṭayel:',
'editfont-default' => 'Sendra do sedaere ṭhikakana',
'editfont-monospace' => 'Monoespeć fonṭ',
'editfont-sansserif' => 'Sans-serif fonṭ',
'editfont-serif' => 'Serif fonṭ',

# Dates
'sunday' => 'Aṭhowar',
'monday' => 'Som',
'tuesday' => 'Mońgol',
'wednesday' => 'Budh',
'thursday' => 'Lukhibar',
'friday' => 'Sokolbar',
'saturday' => 'Sạnicar',
'sun' => 'Aṭhwar',
'mon' => 'Som',
'tue' => 'Mongolbar',
'wed' => 'Budhbar',
'thu' => 'Lukhibar',
'fri' => 'Sokolbar',
'sat' => 'Sạnicar',
'january' => 'Jạnuạri',
'february' => 'Februạri',
'march' => 'Marc',
'april' => 'Epril',
'may_long' => 'Me̠',
'june' => 'Jun',
'july' => 'Julại',
'august' => 'A̠go̠sṭ',
'september' => 'Se̠ṕṭembạ̣r',
'october' => 'O̠ḱ́ṭo̠bo̠r',
'november' => 'Nove̠mbo̠r',
'december' => 'Ḍisembo̠r',
'january-gen' => 'Jạnuạri',
'february-gen' => 'Februạri',
'march-gen' => 'Marc',
'april-gen' => 'Epril',
'may-gen' => 'Me',
'june-gen' => 'Jun',
'july-gen' => 'Julại',
'august-gen' => 'Ago̠sṭ',
'september-gen' => 'Se̠ṕṭembo̠r',
'october-gen' => 'O̠ḱ́ṭo̠bo̠r',
'november-gen' => 'Nove̠mbo̠r',
'december-gen' => 'December',
'jan' => 'Jạn',
'feb' => 'Febr',
'mar' => 'Ma̠r',
'apr' => 'Epr',
'may' => 'Me',
'jun' => 'Ju̠n',
'jul' => 'Ju̠l',
'aug' => 'Ago̠',
'sep' => 'Seṕ',
'oct' => 'Okṭ',
'nov' => 'No̠v',
'dec' => 'Dis',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Bivag|Bivagko}}',
'category_header' => 'Sakam korenaḱ rokom sokom "$1"',
'subcategories' => 'Huḍiń rokom sokomko',
'category-media-header' => '"$1" babot reaḱ rokom sokomte emen meḍiya rẽtko',
'category-empty' => '"Noa rokom sokom sakamre do nit jahan sakam se miḍiya rẽt do bạnuḱa."',
'hidden-categories' => '{{PLURAL:$1|Dãnań renaḱ|Dãnań renaḱ ko}}',
'hidden-category-category' => 'Uku akan rokom sokom ko',
'category-subcat-count' => '{{PLURAL:$2| keṭagorire eken tayom hudińkeṭagori menaḱa. |Noa keṭagorire tayom menaḱa {{PLURAL:$1 hudińkeṭagoriko}}, jotokote $2}}',
'category-subcat-count-limited' => 'Noa rokom sokomre latar reaḱ {{PLURAL:$1 gan kạṭic rokom sokom $1gan kạtic rokom sokom menaḱa}}',
'category-article-count' => '{{PLURAL:$2| Noa keṭagoriredo eken tayomtenaḱ sakam menaḱa.| Tayom {{PLURAL:$2| sakam do |$1 sakamko kana}} nia keṭagorire, sanamkote  hoyoḱkana $2 .}}',
'category-article-count-limited' => 'Noa {{PLURAL:$1 sakam sakamko}} rokom sokomre menaḱa.',
'category-file-count' => '{{PLURAL:$2 Noa babot reaḱ rokom sokomre do eken latar reaḱ sakam menaḱa. Noa babot reaḱ rokom sokomre emakan moṭhe $2 gan sakam mudre {{PLURAL:$1 gan sakam $1 gan sakam}} latarre uduḱ hoena}}',
'category-file-count-limited' => 'Latar reaḱ {{PLURAL:$1 rẽt rẽtko}} noa rokom sokomre menaḱa.',
'listingcontinuesabbrev' => 'Calaḱa',
'index-category' => 'Unuduḱ sakam ko do bạnuḱa',
'noindex-category' => 'Unuduḱ sakamkodo bạnuḱa',
'broken-file-category' => 'Baṅ kạmi daṛeaḱ chubi joṛao soho sakamko',

'about' => 'Lạgitte, Lạgti',
'article' => 'Menaḱakat́ sakam',
'newwindow' => 'Nãwã khiṛki jhijme',
'cancel' => 'Badme',
'moredotdotdot' => 'Aema',
'mypage' => 'In̕aḱ sakam',
'mytalk' => 'Iñaḱ́ ro̠ṛ',
'anontalk' => 'Nui baṅ ńutumanić beoharićaḱ galmarao sakam',
'navigation' => 'Ñamme',
'and' => '&#31;ar',

# Cologne Blue skin
'qbfind' => 'N̕am',
'qbbrowse' => 'Sendra',
'qbedit' => 'Tońge',
'qbpageoptions' => 'Noa sakam',
'qbmyoptions' => 'In̕anḱ sakamko',
'qbspecialpages' => 'Asokay teaḱ sakamko',
'faq' => 'Baḍae kupuliko',
'faqpage' => 'Project:FAQ',

# Vector skin
'vector-action-addsection' => 'Asol katha joṛaome',
'vector-action-delete' => 'Giḍi',
'vector-action-move' => 'Ocoḱ́me',
'vector-action-protect' => 'Bańcao',
'vector-action-undelete' => 'Bań getgiḍi',
'vector-action-unprotect' => 'Bodol rukhiyạ',
'vector-simplesearch-preference' => 'Arhõ jạsti sendra poramorso keṭećmẽ (khali vecṭor skinre lạgit)',
'vector-view-create' => 'Tearme',
'vector-view-edit' => 'So̠mpado̠n',
'vector-view-history' => 'Jạṛ ńelme',
'vector-view-view' => 'Paṛhaḱme',
'vector-view-viewsource' => 'Ńamoḱaḱ ńelme',
'actions' => 'Kạmi',
'namespaces' => 'Ñutum jaiga',
'variants' => 'Etaḱko',

'errorpagetitle' => 'vul',
'returnto' => "$1 te ruar-rok' me",
'tagline' => 'Oka khoć',
'help' => 'Go̠ṛo̠',
'search' => 'Se̠ndra',
'searchbutton' => 'Se̠ndra',
'go' => 'Calaḱme',
'searcharticle' => 'Calaḱme',
'history' => 'Sakam reaḱ jạṛ',
'history_short' => 'Jạṛ',
'updatedmarker' => 'Ińaḱ mucạt hiripor khon nitaḱ halot',
'printableversion' => 'Chapai lekan version',
'permalink' => 'Terejuge joṛao',
'print' => 'Chapa',
'view' => 'Udukme',
'edit' => 'So̠mpado̠n',
'create' => 'Tearme',
'editthispage' => 'Noa sakam joṛaome',
'create-this-page' => 'Noa sakam benao me',
'delete' => 'muchau me',
'deletethispage' => 'Noa sakam do get giḍikam',
'undelete_short' => 'Baṅ getgiḍilena {{PLURAL:$1 1ṭen joṛao $ joṛaoko}}',
'viewdeleted_short' => '{{PLURAL:$1 gan ocoḱ sompadok $1 gan ocoḱ sompadon}} udugmẽ',
'protect' => "banchao'",
'protect_change' => 'Judạ',
'protectthispage' => 'Noa sakam ban̕caome',
'unprotect' => 'Bodol ban̕cao',
'unprotectthispage' => 'Noa sakam reaḱ rukhiyạ bodolmẽ',
'newpage' => 'Nãwã sakam',
'talkpage' => 'Noa sakam galmaraome',
'talkpagelinktext' => 'Ro̠ṛme',
'specialpage' => 'Osokayteaḱ sakam',
'personaltools' => 'Nijaḱ jontropạti',
'postcomment' => 'Nãwã pahaṭa',
'articlepage' => 'Menaḱ sakam uduḱme',
'talk' => 'Galmarao',
'views' => 'Ñel koyoḱ',
'toolbox' => 'Jontopạti baḱso',
'userpage' => 'Laṛcaṛićaḱ sakam uduḱme',
'projectpage' => 'Porjakṭ sakam uduḱme',
'imagepage' => 'Rẽt sakam uduḱme',
'mediawikipage' => 'Mesag sakam uduḱme',
'templatepage' => 'Ṭempleṭ sakam udugmẽ',
'viewhelppage' => 'Goṛoaḱ sakam n̕elme',
'categorypage' => 'Babot reaḱ rokom sokom udugmẽ',
'viewtalkpage' => 'Galmarao ńelme',
'otherlanguages' => 'Eṭagak pạrsi',
'redirectedfrom' => '$1 khon ạcur heć akana',
'redirectpagesub' => 'Bań sojhe sakam',
'lastmodifiedat' => 'Noa sakam do sạjao hoena $1, $2 te',
'viewcount' => 'Noa sakamdo {{PLURAL:$1 dhom $1 dhom}} udug hoena.',
'protectedpage' => 'Rukhíạ sakamko',
'jumpto' => 'Calaḱme :',
'jumptonavigation' => 'Ñamme',
'jumptosearch' => 'Sendra',
'view-pool-error' => 'Ikạkańmẽ, sarvarre nitoḱ do aḍi cap menaḱa.
Ạḍi aema beoharko noa sakam ńel lạgit́ko kurumuṭueda.
Nãwate noa sakam ńel kurumuṭuy lạgit́te dayakate mit́ghạṛi tạṅgiymẽ.
$1',
'pool-timeout' => 'Somoy paromena cạbi lạgit́te tạṅgi hoyoḱkana',
'pool-queuefull' => 'Pul reaḱ sakam perećena',
'pool-errorunknown' => 'Bań baḍayaḱ bhul',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'babo̠tre',
'aboutpage' => 'Project: Babo̠t',
'copyright' => '$1 re bhitrire ńamoḱa.',
'copyrightpage' => '{{ns:project}}: Eḱteạr',
'currentevents' => 'Cạlit ghoṭnako',
'currentevents-url' => 'Project: Nitaḱ evenṭ ko',
'disclaimers' => 'Dạbi bạnuḱko',
'disclaimerpage' => 'Project: Sadharon ḍiskleimarko(General disclaimer)',
'edithelp' => 'Tońge goṛo',
'helppage' => 'Help: Bhitri renaḱ',
'mainpage' => 'Mukhiạ Sakam',
'mainpage-description' => 'Mukhiạ sakam',
'policy-url' => 'Project:Ritiniti',
'portal' => 'Khũṭ boloḱ ho̠r',
'portal-url' => 'Project: Khũṭ bolokt họr',
'privacy' => 'Nijaḱ eḱtear',
'privacypage' => 'Project: Nijaḱ eḱteạr',

'badaccess' => 'Ektiạr vul',
'badaccess-group0' => 'Am do oka kạmi lạgit́em aroj akat́, ona kạmi purạo lạgit́te ạidạri do bạnuḱa.',
'badaccess-groups' => 'Am do oka kạmim menjoṅkan ona do khạli {{PLURAL:$2 rạsiạkore noa rạsiạreaḱ mit́ṭenre}} mitṭen beoharić sompadon daṛeyaḱa: $1.',

'versionrequired' => 'Meḍiawiki reaḱ $1 nãwã aroe jạruṛa',
'versionrequiredtext' => 'Noa sakam beohar lạgit́te meḍiaWikire $1 nambar nãwã araoe jạruṛa.
[[Special:Version nãwã aroe sakam]] ńelmẽ.',

'ok' => 'Ṭhik gea',
'retrievedfrom' => '"$1" khon ñam ạgui',
'youhavenewmessages' => 'Amaḱ do $1 ($2) menaḱa',
'newmessageslink' => 'Nãwã sombat',
'newmessagesdifflink' => 'Mucạt bodol',
'youhavenewmessagesmulti' => 'Amaḱ nãwã mesagko do $1 menaḱa',
'editsection' => 'So̠mpado̠n',
'editold' => 'So̠mpado̠n',
'viewsourceold' => 'Ńamoḱ jayga',
'editlink' => 'Tońge',
'viewsourcelink' => 'vitrireaḱ́ jo̠to̠ ńelme',
'editsectionhint' => 'Sapṛao dhara: $1',
'toc' => 'Menaḱaḱko',
'showtoc' => 'Uduḱme',
'hidetoc' => 'uku, Danaṅ',
'collapsible-collapse' => 'Murchạo caba',
'collapsible-expand' => 'Phaylao',
'thisisdeleted' => '$1 Ńel se nãwã aroe hoyukma?',
'viewdeleted' => '$1 Ńelme',
'restorelink' => '{{PLURAL:$1 mit́ṭen ocoḱgiḍi sompadon $1 gan udug giḍi sompadon}}',
'feedlinks' => 'Jom oco',
'feed-invalid' => 'Garhak feed reaḱ rokom do ạnlekate baṅkana',
'feed-unavailable' => 'Sinḍikason feed do baṅ ńamoḱkana',
'site-rss-feed' => '$1 RSS feed',
'site-atom-feed' => ' $1 Jom oco',
'page-rss-feed' => '"$1" RSS feed',
'page-atom-feed' => '"$1" khon khudri jom',
'red-link-title' => '$1 (niạ sakamdo bạnuḱa)',
'sort-descending' => 'Ulṭạo horop lekate sajao',
'sort-ascending' => 'Horop lekate sajao',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Sakam',
'nstab-user' => 'Laṛcaṛicaḱ sakam',
'nstab-media' => 'Midiạ sakam',
'nstab-special' => 'Jạruṛ pata',
'nstab-project' => 'Porject reaḱ sakam',
'nstab-image' => 'Fail',
'nstab-mediawiki' => 'Mesag',
'nstab-template' => 'Sajao sakam',
'nstab-help' => 'Goṛo sakam',
'nstab-category' => 'Juṛu ko',

# Main script and global functions
'nosuchaction' => 'Noṅkanaḱ kạmi bạnuḱa',
'nosuchactiontext' => 'Noa URL re goṭa akan kạmi do ạnlekate baṅkana.
Am do paseć mit́ṭen vul joṛaoem emakada se URL oltem vul akada.
Noa do noṅkanaḱ menkana je {{SITENAME}} sayeṭre beoharen sofṭower re mit́ṭen vul menaḱa.',
'nosuchspecialpage' => 'Noṅkanaḱ asokay sakam do banuḱa',
'nospecialpagetext' => '<strong>Am do mit́ṭen beạn asokae sakamem nehor akada.</strong>
[[Special:SpecialPages {{int:specialpages}}]]-re ạn asokae sakamkore mit́ṭen tạlikam ńama.',

# General errors
'error' => 'bhul',
'databaseerror' => 'Ḍaṭabase vul',
'laggedslavemode' => "'''Sontoroḱme:''' sakamre do nahaḱ nãwãnaḱko paseć bạnuḱa.",
'readonly' => 'Ḍaṭabes do talagea',
'enterlockreason' => 'Cạbie reaḱ karon do cet́kana ma lạimẽ, Saõte tinre tala cạbim jhija ona okte hõ lạimẽ',
'readonlytext' => 'Nãwã hataen ar eṭagaḱ sompadon lạgit́te ḍaṭabes do nit bondo gea. Paseć ḍaṭabes rukhiyạre niyom lekate kạmi calaḱ kana. Thoṛa ghạrịić porte laha obosthare acur hạjuḱa.
Sasetić do noa kathae roṛ keda: $1',
'missing-article' => '"$1" $2 noa ńutumanaḱ sakhiyạ̣t sakamre olakanaḱ do bań ṅamoka.
Noa hoy renaḱ karon do hoyoḱkana cabak tạrik pharak se noare joṛao sakam do get́ giḍi akana.
Judi noa do karon bań hoylen khan, noa do am sopṭoyer re kạtićtem ńam daṛeyaḱa.
Daya katet́ noa do nonde [[Special:ListUsers/sysop|administrator]],  ṭhen lạime, URL hotete.',
'missingarticle-rev' => '(Nãwã aro#: $1)',
'missingarticle-diff' => '(Pharak: $1, $2)',
'readonly_lag' => 'Ḍaṭabes do aćhote tege bondo hoe akana, je lekate udhin reaḱ ḍaṭabes sarvarkor mukhiạ ḍaṭabes sarvar lekate heć daṛeaḱ.',
'internalerror' => 'Bhitri reaḱ bhul',
'internalerror_info' => 'Bhitri reaḱ vul: $1',
'fileappenderrorread' => 'Jońṛao oktere "$1" baṅ paṛhaolena.',
'fileappenderror' => '"$1" do "$2" saõte joṛao baṅ ganoḱ kana.',
'filecopyerror' => '"$1" rẽt khon "$2" rẽt baṅ kopilena.',
'filerenameerror' => '"$1" rẽt reaḱ ńutum bodol kate "$2" em baṅ hoyoḱ kana.',
'filedeleteerror' => '$1 sakam do baṅ get́ giḍiḱ lena',
'directorycreateerror' => '"$1" dayrekṭori do baṅ tearlena.',
'filenotfound' => '"$1" rẽt do baṅ sendra ńamoḱ kana.',
'fileexistserror' => '"$1" rẽtre baṅ oloḱ kana: Rẽt do lahare menaḱa.',
'unexpected' => 'Baṅ asakan mạn: "$1"="$2".',
'formerror' => 'Vul: forom do baṅ jimạlena.',
'badarticleerror' => 'Noa sakamre kạmiko do baṅ puraolena.',
'cannotdelete' => '$1 sakam se rẽt do baṅ get giḍilena.
Pasec eṭaḱ hoṛ noa do lahareko get giḍi akada.',
'cannotdelete-title' => '"$1" Sakam do baṅ get giḍiḱkana',
'badtitle' => "barich' bishó́́́́y",
'badtitletext' => 'Amaḱ nehorakaḱ sakam ńutum do bań puraoa, bạnuka, se be sudhrạo joṛao bhitri katha se bhitri wiki ńutum.
Noa re do mit se aema bisó menaḱa oka do ńutumre bań beoharok.',
'querypage-no-updates' => 'Noa sakam reaḱ nahaḱ halot bondo gea. Nonḍe doho akana ḍaṭako do baṅ saphaḱa.',
'wrong_wfQuery_params' => 'wfQuery ()-re vul perameṭar em hoeakana<br />
Fańson: $1<br />
Query: $2',
'viewsource' => 'Vitrireaḱ ńelme',
'viewsource-title' => '$1 renaḱ ńamoḱ ṭhại ńelmẽ',
'actionthrottled' => 'Kạmi reaḱ dhara bại',
'protectedpagetext' => 'Noa sakam do ol toṅge lạgit́te do bańcao gea.',
'viewsourcetext' => 'Noa sakam do am ńel ar ńamoḱaḱ ṭhạiem kopi hatao daṛeaḱa:',
'viewyourtext' => "Am do '''Amaḱ sompadon''' noa sakam ńel arem kopi hatao daṛeaḱa:",
'protectedinterface' => 'Noa sakam reaḱ babotko do wiki sofṭoyer reaḱ mit́ṭen inṭarfes khobore ema, onate noa do rukhiyạ doho hoeakana.',
'cascadeprotected' => 'Noa sakam do sompadon khon rukhiyạre menaḱa, karon sakam do latar reaḱ {{PLURAL:$1 gan sakam reaḱ gan sakam reaḱ}} bhitrire, oka sakam do (cascading) te rukhiyạ menaḱa:
$2',
'namespaceprotected' => "Amaḱ do sakamko joṛao lạgit́te ạidạri banuḱ tama '''$1''' ńutumjayga.",
'ns-specialprotected' => 'Asokay teaḱ sakamkodo baṅ oltoṅgea.',

# Virus scanner
'virus-badscanner' => 'Vul konfigareson: baṅ orom vairas skenar: "$1"',
'virus-scanfailed' => 'Esken baṅ hoelena (Code $1)',
'virus-unknownscanner' => 'Baṅ urum anṭvayras:',

# Login and logout pages
'welcomeuser' => 'Johar',
'welcomecreation-msg' => 'Amaḱ ekaunṭ do̠ jhićena. Amaḱ pạsindko bodol alom hiṛińa.',
'yourname' => 'Beoboharicaḱ ńutum',
'userlogin-yourname-ph' => 'Amaḱ beohar ńutum emme.',
'yourpassword' => 'Uku namber',
'yourpasswordagain' => 'Arhõ oku namber olme',
'remembermypassword' => 'Mitṭen khon bạṛti khata reaḱ cạbi disạ dohoḱma (Jạsti $1 {{PLURAL:$1 din reaḱ din reaḱ}} lạgit)',
'yourdomainname' => 'Amaḱ ḍomen:',
'externaldberror' => 'Hoe daṛeyaḱa jahan bahre reaḱ jacaeaḱ ḍaṭabes vul hoeakana se amaḱ bahre reaḱ ekaunṭ do nahaḱ halot aguire ạidạri bạnuḱa.',
'login' => "bolok' duar",
'nav-login-createaccount' => 'Boloḱ́ duạr / ekaunt tearme',
'loginprompt' => '{{SITENAME}}-re boloḱem meneḱ khan amaḱ sendrare kuki kạmi ehoṕ hoyoḱtama.',
'userlogin' => 'Bhitri bolon / ekaunṭ tear',
'userloginnocreate' => 'Bhitri bolo',
'logout' => 'Bahre oḍoń',
'userlogout' => 'Bahre oḍoń',
'notloggedin' => 'Bhitri baṅ bolokana',
'nologin' => "Amaḱ do cet́ wikipeḍiare ekaunṭ banuḱtama? Ado '''$1'''",
'nologinlink' => 'account tear me',
'createaccount' => 'Ṭhai benaome',
'gotaccount' => 'Amaḱ do cet́ miṭten ekaunṭ tear menaḱtama? $1 tearmẽ.',
'gotaccountlink' => 'Bhitri bolon',
'userlogin-resetlink' => 'Amaḱ boloḱ talam cạbi sanamem hiṛińkeda?',
'createaccountmail' => 'E-mail hotete',
'createaccountreason' => 'Karon',
'badretype' => 'Am do okaṭaḱ oku nambarkom em keda ona do baṅ milạolena.',
'userexists' => 'Laṛcaṛicaḱ ńutum em hoyena ona do beohar hoyakana.
Dayakatet́ eṭagaḱ ńutum bachaome.',
'loginerror' => 'Bhitri bolok do vulgea',
'createaccounterror' => 'Ekaunṭ do baṅ tear lena: $1',
'nocookiesnew' => 'Beoharićaḱ ekaunṭ tear hoe akana, menkhan am do nit hạbićte ekaunṭre bam boloakana. {{SITENAME}} re kuki beohar kate beoharićaḱ ekaunṭre boloa.
Amaḱ sendrare kukiko bondo hoeakana. Dayakate kukiko kạmi hoe ocoemẽ ar amaḱ nãwã beohar ńutum ar uku nambar beohar hotete noa ekaunṭre boloḱmẽ.',
'nocookieslogin' => '{{SITENAME}} re kuki hotete beoharićaḱ bhitri boloḱ do hoyoḱa. Amaḱ sendrare kuki bondo menaḱa. Kuki cạlu kate arhõ kurumuṭuimẽ.',
'nocookiesfornew' => 'Beoharićaḱ ekaunṭ do baṅ tear akana, Cedaḱ je noa ńamoḱ jaega babote ale do bale uruma.
Ale do baḍae ocolem amaḱ kuki doe kạmikana, sakam do arhõ rakaṕ lạgit́te kurumuṭuemẽ.',
'noname' => 'Am do asol beoharićaḱ ńutum ṭhikte bam emakada.',
'loginsuccesstitle' => 'Bhitri boloḱ do moctege puraoena',
'loginsuccess' => "'''Am do nitge \"\$1\" ńutumte {{SITENAME}} rem bolo akana.'''",
'nosuchuser' => '"$1" ńutuman jahan beoharić bạnuea.
Beoharićaḱ ńutum do bukṛogea.
Amaḱ bananko ńelmẽ, se [[Special:Userlogin/signup nãwã mit́ṭen ekaunṭ tearmẽ]].',
'nosuchusershort' => '"$1" ńutuman jahãe beoharko do banuḱkoa. Ńutum reaḱ banan biḍaomẽ.',
'nouserspecified' => 'Am do pusṭaote laṛcaṛićaḱ ńutum em hoyoḱtama.',
'login-userblocked' => 'Nui laṛcaṛic doe esetgea. bhitri boloḱ ạidạri bań emoḱ kana.',
'wrongpassword' => 'Bań milaoaḱ oku nambar em hoyakana.
Daya kate arhõ mitdhom kurumuṭuyme.',
'wrongpasswordempty' => 'Em hoyen oku nambar do cetge banuḱa.
Daya katet́ arhõ kurumuṭuyme.',
'passwordtooshort' => 'Uku nambar do {{PLURAL:$1 1 horop reaḱ $1 horop reaḱ}} mudre hoyoḱ jạruṛa.',
'password-name-match' => 'Amaḱ oku nambar do amaḱ ńutum khon eṭaḱ hoyoḱ jạruṛtama.',
'password-login-forbidden' => 'Noa laṛcaṛicaḱ ńutum ar oku nambar do ạnlekate baṅkana.',
'mailmypassword' => 'E-mail reaḱ nãwã uko katha',
'passwordremindertitle' => 'Nãwã nitlạgit oku nambar {{SITENAME}} lạgit́te',
'noemail' => '"$1" beoharić lạgit́te do jahan e-mail ṭhikana rukhiyạ doho bạnuḱa.',
'noemailcreate' => 'Am do mitṭen jewet e-mail ṭhikạna em jaruṛ menaḱtama.',
'passwordsent' => '"$1" ṭhikạnate resṭariyen e-mail lạgit́te mitṭen oku nambar em hoyena.
Daya kate ńam porte arhõ bhitri boloḱme.',
'blocked-mailpassword' => 'Amaḱ IP ṭhikạna khon sompadon do bondo menaḱa, Onate noa ṭhikạna baṅ beohar kate uku nambar ruạṛ baṅ hoyoḱa.',
'mailerror' => 'E-mail kulte eṭkẽṭõrẽ: $1',
'emailauthenticated' => 'Amaḱ e-mail ṭhikạna do $2 tạrikh reaḱ $3 re jạhirena.',
'emailnotauthenticated' => 'Amaḱ e-mail reaḱ ṭhikạna do <strong> nit hõ baṅ jacay akana</strong> latar reaḱ features lạgit́te jahan e-mail do baṅkuloḱa.',
'noemailprefs' => 'Noa features ko kạmie ocoy lạgit́te mit́ṭen e-mail ṭhikạna dohoe hoyoḱa.',
'emailconfirmlink' => 'Amaḱ e-mail ṭhikana do sạriyme.',
'invalidemailaddress' => 'Noa e-mail ṭhikạna do baṅ hataoa, karon noa formeṭ do pusṭạote baṅ em akana. Dayakate pusṭao formeṭte ṭhikạna emmẽ, se khet do khạliemẽ.',
'cannotchangeemail' => 'Ekaunṭ e-mail ṭhikạnakodo noa wiki re baṅ bodoloḱ kana.',
'emaildisabled' => 'Noa sayeṭre do e-mail em subita bạnuḱa.',
'accountcreated' => 'Ekaunṭ do teyarena',
'accountcreatedtext' => '$1 lạgit́te ekaunṭ do benaoena.',
'createaccount-title' => '{{SITENAME}} lạgit́te ekaunṭ benao',
'createaccount-text' => 'Okoe co am lạgit́te mitṭen ekaunṭko amaḱ e-mail ṭhikạna lạgit {{SITENAME}} re ($4) ńutum "$2", oku nambar "$3".
Am do mesagem baṅ daṛeyaḱa, judi noa ekaunṭ do vulge benaolen khan.',
'usernamehasherror' => 'Beoharićaḱ ńutumre hes horop baṅ tahẽdaṛeaḱa',
'login-throttled' => 'Am do mitghạri lahare por por aema dhao boloḱem kurumuṭu keda.
Arhõ kurumuṭue lahare dayakate thoṛagan tạṅgiemẽ.',
'login-abort-generic' => 'Amaḱ bhitri boloḱ do baṅ hoylena - batena.',
'loginlanguagelabel' => 'katha: $1',

# Email sending
'user-mail-no-addy' => 'Jahan e-mail ṭhikana bạgi kate e-mail kul kurumuṭu hoena.',

# Change password dialog
'resetpass' => 'Oku nambar bodol',
'resetpass_header' => 'Ekaunṭ oku namber bodol',
'oldpassword' => 'Mare uku nombor',
'newpassword' => 'Nãwã oku nomber',
'retypenew' => 'Doṛhate oku namber olme',
'resetpass_submit' => 'Oku namber joṛao ar bhitri bolok',
'changepassword-success' => 'Amaḱ oku namber do napayte bodolena!
Nitoḱ do am bhitritem boloḱkana...',
'resetpass_forbidden' => 'Oku namber do baṅ bodoloklena',
'resetpass-no-info' => 'Noa sakam sojhete laṛcaṛ lạgit́te am do bhitri boloḱ hoyoḱtama.',
'resetpass-submit-loggedin' => 'Oku namber bodol',
'resetpass-submit-cancel' => 'Bạgi',
'resetpass-temp-password' => 'Nit lạgit uku nambar:',

# Special:PasswordReset
'passwordreset' => 'Nãwãte oku nambar emme',
'passwordreset-legend' => 'Nãwãte oku nambar emme',
'passwordreset-disabled' => 'Noa wikire amaḱ uku nambar nãwãte em lạgit subita do bando gea.',
'passwordreset-username' => 'Beoharicaḱ ńutum:',
'passwordreset-domain' => 'Ḍomen:',
'passwordreset-capture' => 'Sendra fol reaḱ e-mail ńelmẽ?',
'passwordreset-capture-help' => 'Am do judi noa jacạy baksom lin lekhan, tobe nit lạgit́te em akan uku nambar são mit́ṭen e-mail ame uduḱama ar ona sãote beoharić ṭhen ona kuluḱa.',
'passwordreset-email' => 'E-mail ṭhikạna:',
'passwordreset-emailtitle' => '{{SITENAME}} sayeṭre beoharićaḱ purạo thutiko',
'passwordreset-emailelement' => 'Beoharićaḱ ńutum: $1
Mit́ ghạṛi lạgit uku nambar: $2',
'passwordreset-emailsent' => 'Mitṭen disạ ruaṛ e-mail do kulena.',
'passwordreset-emailsent-capture' => 'Mit́ṭen disạ ruaṛaḱ e-mail dokulena, oka do latarre ńeloḱ kana.',
'passwordreset-emailerror-capture' => 'Disạ ruạṛ oco lạgit́te mit́ṭen e-mail tear hoelena, oka do latarre udugoḱkana, menkhan $1 beoharić ṭhen  ṭhen baṅ kul hoe akana.',

# Special:ChangeEmail
'changeemail' => 'E-mail ṭhikạna do bodolme',
'changeemail-header' => 'Ekaunṭ e-mail ṭhikạna do bodolme',
'changeemail-text' => 'Amaḱ e-mail ṭhikạna bodol lạgit́te noa forom purao me. Am do noa sariyaḱ lạgit́te amaḱ oku nambar em jạruṛtama.',
'changeemail-no-info' => 'Noa sakam sojhete laṛcaṛ lạgit́te am do bhitri boloḱ hoyoḱtama.',
'changeemail-oldemail' => 'Nitaḱ e-mail ṭhikạna:',
'changeemail-newemail' => 'Nãwã e-mail ṭhikạna:',
'changeemail-none' => '(Okaṭaḱ hõ baṅ)',
'changeemail-submit' => 'E-mail bodolme',
'changeemail-cancel' => 'Badme',

# Edit page toolbar
'bold_sample' => 'Moṭa onol',
'bold_tip' => 'Moṭa onol',
'italic_sample' => 'Beka onol',
'italic_tip' => 'Beka onol',
'link_sample' => 'Joṛaotet́ reaḱ bohoḱ',
'link_tip' => 'Bhitri reak joṛaotet́',
'extlink_sample' => 'http://www.nạmuna.makaṛgạṭi ạmạli',
'extlink_tip' => 'Baherenaḱ jońṛao (disạyme http://prefix)',
'headline_sample' => 'Bohok katha',
'headline_tip' => 'level 2 guḍkatha',
'nowiki_sample' => 'Begor format olko bhoraome',
'nowiki_tip' => 'wiki formatting bạgiyaḱme',
'image_tip' => 'Tol Fael',
'media_tip' => 'file reaḱ jońṛao',
'sig_tip' => 'Amaḱ suhi sãote okte',
'hr_tip' => 'Barabạri dag',

# Edit pages
'summary' => 'Guṭ katha',
'subject' => 'Bisoy/Bohoḱ katha:',
'minoredit' => 'Noa do hudiń joṛao kami',
'watchthis' => 'Noa sakam ńelme',
'savearticle' => 'Sakam dohoeme',
'preview' => 'Ńel, Unuduḱ',
'showpreview' => 'Unuduḱ',
'showlivepreview' => 'Jewet uduk',
'showdiff' => 'Bodolko ńeloḱma',
'anoneditwarning' => "'''Sabdhan:''' amdo begor logkatem bolowakana.
Amaḱ IP ṭhikana do noa sakam sompadon jạṛre rekorḍoḱa.",
'anonpreviewwarning' => '"Am do bhitri bam bolo akana. Noa sakamre amaḱ kạmiko jạre IP ṭhiikạ̣nare rukhiyạ ḱa."',
'missingcommenttext' => 'Daya kate amaḱ menaḱ katha latare olmẽ.',
'summary-preview' => 'Guṭ katha unuduḱ:',
'subject-preview' => 'Babot/Guṭkatha unuduḱ:',
'blockedtitle' => 'Beoharić doe eset ocoakana.',
'blockednoreason' => 'jahan babot baṅ em akana',
'whitelistedittext' => 'Sakamre sompadon lạgit́te $1 em hoyoḱa.',
'nosuchsectiontitle' => 'Pahaṭa bȧn ńamlena',
'loginreqtitle' => 'Boloḱ jạruṛa',
'loginreqlink' => 'Bhitri boloḱ',
'loginreqpagetext' => 'Eṭagaḱ sakamko ńel lạgit́te do am $1 hoyoḱ jạruṛtama.',
'accmailtitle' => 'Uku nambar do kulena.',
'accmailtext' => '[[User talk:$1 $1]] lạgit́te aćte benaoen uku nambar do $2 kul hoena.
Bhitri bolo kateḱ noa nãwã ekaunṭ lạgit uku nambar "[[Special:ChangePassword Change password]]" sakam khonem bodol daṛyakya.',
'newarticle' => '(Nãwa)',
'newarticletext' => "Am do oka mitṭen joṛaoem pańja akada, onaṭak do bạnuḱa.
Ona sakam tear lạgit́te, latar reaḱ baksore ol ehoṕmẽ (arhõ jạsti baḍae lạgit́te [[{{mediaWiki:Helppage}}help page]] pańjaemẽ).
Am do judi nonḍe vulkatem heć akan khan, tobe amaḱ sendrakore '''back''' baṭon linmẽ.",
'noarticletext' => 'Nitoḱ noa sakamre do ol bạnuḱa.

You can [[Special:Search/{{PAGENAME}}|search for this page title]] in other pages,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs],
or [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page]</span>.',
'noarticletext-nopermission' => 'Noa sakamre do nitoḱ o̠l banuḱa.

You can [[Special:Search/{{PAGENAME}}|search for this page title]] in other pages,
or <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs]</span>.',
'userpage-userdoesnotexist' => '"<nowiki>$1</nowiki>" ńutuman jahãe beoharićaḱ ekaunṭ do baṅ resṭri hoeakana. Daya kate biḍạo katet́ ńelmẽ noa sakam do benoa/sompadonem menet́ kana se baṅ.',
'userpage-userdoesnotexist-view' => 'Beoharićaḱ "$1" ekaunṭ do baṅ resṭire akana.',
'blocked-notice-logextract' => 'Nui beoharić do nitoḱe esetgea.
Refarens lạgit́te nahaḱ boloḱ do latare em hoena:',
'updated' => '(Halot ruaṛ)',
'note' => "'''Noṭ:'''",
'previewnote' => "'''kheyalmẽ, noa do eken ńeloḱ lạgit.'''
Amaḱ bodolaḱ kodo nit habićte bań rukhíạakana!",
'continue-editing' => 'Toṅge calaḱkana',
'editing' => 'Joṛao do purạena: $1',
'creating' => '$1 sakam doe tear akada',
'editingsection' => 'Joṛao $1 (hạṭiń)',
'editingcomment' => 'Sompadon akadae $1 (Nãwa pahaṭa)',
'editconflict' => 'Sompadon reaḱ bene bạiri: $1',
'yourtext' => 'Amaḱ ol',
'storedversion' => 'Rukhiyạ nãwã aroe',
'nonunicodebrowser' => "'''Sontoro: Amaḱ sendra reaḱ eunikoḍ-gate sompok baṅ kana. Am do je lekate apod baṅ hoe kate noam sompadon daṛeaḱ, ona lạgit́ somadhan menaḱa: baṅaski karecṭarko do heskaḍesimal koḍ hisạbte udug hoyoḱa.'''",
'yourdiff' => 'Farak',
'templatesused' => 'Noa sakamre beoharen {{PLURAL:$1 ṭempeleṭ ṭempeleṭko}}:',
'template-protected' => 'Rukhiạ',
'template-semiprotected' => '(Kạṭic-rukhiyạ)',
'hiddencategories' => 'Noa sakam do {{PLURAL:$1 1 ukuakan bhag $1 uku akan bhagkorenaḱ}} gaõtarenge:',
'nocreate-loggedin' => 'Nãwã sakam tear lạgit́te am do ạidạri em baṅ hoeakana.',
'sectioneditnotsupported-title' => 'Pahaṭa sompadona do bae hataoeda',
'sectioneditnotsupported-text' => 'Noa sompadona sakamre pahaṭa sompadona do bae hataoeda',
'permissionserrors' => 'Ạidạri vulko',
'permissionserrorstext' => 'Noa kạmi amaḱ ạidạri do banuḱa, {{PLURAL:$1 gan karon reaḱ gan karon reaḱ}} lạgit:',
'permissionserrorstext-withaction' => 'Amaḱ $2 kạmire ạydạri do bạnuḱa, Ona reaḱ {{PLURAL:$1 Karon/ Karonko}}:',
'recreate-moveddeleted-warn' => "'''Sontorokme: am do arhõ doṛhate sakamem teyareda oka do sedayre get giḍiyen.
Am do gunạnme cet́ noa joṛao kạmi am lạgit́te ganoḱ ase bań.
Noa get ar tala ocok sakam nonḍe em hoyena dhok lagit́te.",
'moveddeleted-notice' => 'Noa sakam do get giḍiyakana.
Get ar ocoḱ giḍi sakam do latarre emakan reference lạgit em hoena.',
'log-fulllog' => 'Joto cạbi udugmẽ',
'edit-hook-aborted' => 'Huk hotete joto sompadonko bạgi hoeakana.
Noa reaḱ jahan katha do bạnuḱa.',
'edit-gone-missing' => 'Sakam do baṅ halot ruạṛlena.
Pasecc: sakam do ocoǵ hoeakana.',
'edit-conflict' => 'Sompadon reṭepeṭe.',
'edit-no-change' => 'Amaḱ sompadon do baṅ hataolena, Cedaḱ je olre jahan bodol bạnuḱa.',
'edit-already-exists' => 'Nãwã sakam baṅ tear lena.
Sakam do laha khon menaḱgea.',
'defaultmessagetext' => 'Sedae olko',

# Parser/template warnings
'post-expand-template-inclusion-warning' => '"Sontoroḱme" Noa format do lạṭu geya.
Thoṛa format do noare banuḱana.',
'post-expand-template-inclusion-category' => 'Sakamko oka borḍre noa tahẽna ona doe paromkeda',
'post-expand-template-argument-warning' => "'''Sontoroḱmẽ:''' Noa sakamre komse kom mitṭen forma joṛao menaḱa ạḍi lạṭute pasnao akana.
Onate noa ạrgumenṭkodo bạgi giḍi hoena.",
'post-expand-template-argument-category' => 'Bagi forma ạrgumenṭ sapdoho sakam',

# Account creation failure
'cantcreateaccounttitle' => 'Ekaunṭ do baṅ tearlena',

# History pages
'viewpagelogs' => 'Noa sakam reaḱ cạbi udukme',
'nohistory' => 'Noa sakam re do jahan sompadon reaḱ jạṛ bạnuḱa.',
'currentrev' => 'Mucạt nãwã aroe',
'currentrev-asof' => 'Mucạt nãwã aroy',
'revisionasof' => 'Nãwã aro sakam $1 leka',
'revision-info' => 'Ńel/pańja ruạṛ $1 khon $2',
'previousrevision' => 'Pạhilaḱ paṛhao ruạṛ',
'nextrevision' => "nãwate n'el ruar",
'currentrevisionlink' => 'Nitoḱaḱ nãwa aroy',
'cur' => 'Boge',
'next' => 'Laha seć',
'last' => 'Laha renaḱ',
'page_first' => 'Pahilaḱ',
'page_last' => 'Mucạt́aḱ',
'histlegend' => "Farak bachao: oka nãwã aroeko tulạoem menet́kan, onako cinhạ em kate boloḱ se latar baṭon linmẽ.<br />
Unuduḱ: '''({{int:cur}})''' = nahaḱ nãwã aroeko saõte tulạo, '''({{int:last}})''' = laha reaḱ nãwã aroe sãote tulạo, '''{{int:minoreditletter}}''' = huḍiń sompadon.",
'history-fieldset-title' => 'Sendray jaṛ',
'history-show-deleted' => 'khạli get giḍiyaḱ koge',
'histfirst' => "adi laha-ak'",
'histlast' => 'Nahak',
'historysize' => '({{PLURAL:$1 1 bayeṭ $1 bayeṭko}})',
'historyempty' => '(banuḱa)',

# Revision feed
'history-feed-title' => 'Jạṛ nãwã aroy',
'history-feed-description' => 'Noa wikire noa sakam reaḱ nãwã aroe jạṛ',
'history-feed-item-nocomment' => 're',

# Revision deletion
'rev-deleted-comment' => '(Sompadon reaḱ guṭ katha do ocoǵ hoena)',
'rev-deleted-user' => '(laṛcaṛić ńutum ocoḱena)',
'rev-deleted-event' => '(Log kạmi do ocog hoena)',
'rev-deleted-user-contribs' => '[Beoharićaḱ ńutum se IP ṭhikạna do ocog hoena - kạmi khon sompadon do uku hoe akana]',
'rev-delundel' => 'ńeloḱ/danaṅ',
'rev-showdeleted' => 'Uduḱme',
'revisiondelete' => 'Get giḍi/nãwã aro baṅ getgiḍi',
'revdelete-nologtype-title' => 'Jahan cạbi ṭayep baṅ em emakana',
'revdelete-nologtype-text' => 'Am do paseć noa kạmie lạgit́te jahan cạbi bam bachao akada.',
'revdelete-show-file-submit' => 'Hẽ',
'revdelete-hide-text' => 'Nãwã aroe olko ukuemẽ',
'revdelete-hide-image' => 'Rẽt reaḱ babotko ukue mẽ',
'revdelete-hide-name' => 'Kạmi ar bejha ukue mẽ',
'revdelete-hide-comment' => 'Sompadon gut katha ukue mẽ',
'revdelete-hide-user' => 'Sompadonićaḱ beohar ńutum/IP ṭhikạna ukuemẽ',
'revdelete-radio-same' => '(alom bodola)',
'revdelete-radio-set' => 'Hẽ',
'revdelete-radio-unset' => 'Baṅ',
'revdelete-log' => 'Babot:',
'revdel-restore' => 'Judạ lekate ńel',
'revdel-restore-deleted' => 'giḍikaḱ ńel ruạṛ',
'revdel-restore-visible' => 'Ńeloḱ leka paṛhao ruạṛ',
'pagehist' => 'Sakam reaḱ jạṛ',
'deletedhist' => 'Get giḍi jạṛ',
'revdelete-reasonotherlist' => 'Eṭaḱak karon',

# History merging
'mergehistory-reason' => 'Babot:',

# Merge log
'revertmerge' => 'bań mit́',

# Diffs
'history-title' => '"$1": Jạṛ nãwã aroe',
'lineno' => 'Sạr $1:',
'compareselectedversions' => 'Noa barea nãwã bachawanaḱ talare tolonayme',
'editundo' => 'ruạṛ',
'diff-multi' => '({{PLURAL:$2 mit́ṭen beoharic $2 hoṛ beoharkin}} Sompadon hoena {{PLURAL:$1 mit́ṭen do mitghạṛi lạgit sudhrạo mit́ṭen do mitghạṛi lạgit sudhrạo}} baṅ uduḱlena.)',

# Search results
'searchresults' => 'Se̠ndra fo̠l',
'searchresults-title' => '"$1"  renaḱ Sẽndra  phol',
'prevn' => 'Laha reaḱ {{PLURAL:$1|$1}}',
'nextn' => 'Táyom teaḱ {{PLURAL:$1|$1}}',
'prevn-title' => 'Laha renaḱ sakam $1 {{PLURAL:$1|result|results}}',
'nextn-title' => 'Tayom $1 {{PLURAL:$1|result|results}}',
'shown-title' => 'Mit́ ṭen kateć sakam $1 {{PLURAL:$1|result|results}} nelmẽ',
'viewprevnext' => 'Ńelme ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists' => "'''Noa wiki re do \"[[:\$1]] ńutum sakam menaḱa",
'searchmenu-new' => 'wiki re [[:$1]]nãwã sakam tear',
'searchprofile-articles' => 'Menaḱaḱ sakamko',
'searchprofile-project' => 'Go̠ṛo ar Project sakam',
'searchprofile-images' => 'Multimedia',
'searchprofile-everything' => 'Sanamaḱ koge',
'searchprofile-advanced' => 'Sompadon',
'searchprofile-articles-tooltip' => '$1 re ńelme',
'searchprofile-project-tooltip' => '$1 re sẽndraeme',
'searchprofile-images-tooltip' => 'File sendra',
'searchprofile-everything-tooltip' => 'Sanam ko modre sẽndra ( roṛ sakam modre hõ)',
'searchprofile-advanced-tooltip' => 'Judạ ńutum re sẽndra',
'search-result-size' => '$1 ({{PLURAL:$2 1 Aṛaṅ$2 Aṛaṅko}})',
'search-result-category-size' => '{{PLURAL: $1 1 gãoren $1 gãota renko}} ({{PLURAL: $2 1 kạṭic rokom sokom $ 2 goṭen}}, {{PLURAL:$3 1 rẽt $3 rẽtko}})',
'search-redirect' => '($1 te sujhi doṛha )',
'search-section' => '(Pahaṭa $1)',
'search-suggest' => 'Am do cet́ $1 em menocoyet tãhẽkana',
'search-interwiki-caption' => 'Hopon porjekṭko',
'search-interwiki-default' => '$1 folko:',
'search-interwiki-more' => '(Arhõ)',
'searchrelated' => 'songenko',
'searchall' => 'Sanam',
'showingresultsheader' => "'''$4'''  lạgit́ {{PLURAL:$5|Pho̠l ńamoḱ́akan - '''$1''' of '''$3'''|Pho̠l ńamoḱ́akan '''$1 - $2''' of '''$3'''}}",
'search-nonefound' => 'Kupuli leka roṛruạṛ bạnuḱa',
'powersearch-togglelabel' => 'Sendra',
'powersearch-toggleall' => 'Sanamaḱ',
'powersearch-togglenone' => 'Okaṭaḱ hõ baṅ',

# Preferences page
'preferences' => 'Pạsindko',
'mypreferences' => 'Iñaḱ pạsindko',
'changepassword' => 'Uku nombor bodolme',
'prefs-skin' => 'Harta',
'skin-preview' => 'Ńel, Unuduḱ',
'datedefault' => 'Pạsind banuḱa',
'prefs-resetpass' => 'Uku nombor bodolme',
'prefs-changeemail' => 'E-mail ṭhikạna bodolme',
'prefs-setemail' => 'E-mail ṭhikana benaome',
'saveprefs' => 'Rukhiyạymẽ',
'resetprefs' => 'Baṅ rukhiyạaḱ ocogmẽ',
'rows' => 'Sạrko:',
'searchresultshead' => 'Sendra',
'timezoneregion-africa' => 'Aphrika',
'timezoneregion-america' => 'Amirika',
'timezoneregion-asia' => 'Esiya',
'timezoneregion-australia' => 'Ausṭralia',
'prefs-files' => 'Rẽtko',
'youremail' => 'E-mail:',
'username' => 'Beoharićaḱ ńutum:',
'uid' => 'Beoharićaḱ cinhạo nombor',
'yourrealname' => 'Sạri ńutum',
'yourlanguage' => 'Pạrsi:',
'gender-male' => 'Baba hoṛ',
'gender-female' => 'Gogo hoṛ, Kuṛi, Kuṛi gidrạ',
'email' => 'E-mail',
'prefs-help-email' => 'E-mail ṭhikana do bạṛtitege, menkhan uku namber nãwãte benao jạruṛa, am do amaḱ uku nomborem hiṛiń keda.',
'prefs-help-email-others' => 'Am são e-mail hotete jogajog dohoy lạgitte mitṭen joṛao se amaḱ katha roṛaḱ sakam bachao jońme.
Amaḱ e-mail ṭhikạna do bań cabaḱa tinre onko do ko beohara',

# User preference: email validation using jQuery
'email-address-validity-valid' => 'E-mail ṭhikạna do jewetge ńamena',
'email-address-validity-invalid' => 'Amaḱ jewet e-mail ṭhkạna emmẽ',

# User rights
'userrights' => 'Beoharićaḱ laṛcaṛ ektiạrko',
'userrights-lookup-user' => 'Beoharkoaḱ gãotako laṛcaṛ',
'userrights-user-editname' => 'Beoharićaḱ ńutum emmẽ',
'editusergroup' => 'Beoharićaḱ gãotako toṅgeymẽ',
'userrights-editusergroup' => 'Beoharićaḱ gãotako toṅgeymẽ',
'saveusergroups' => 'Beoharićaḱ gãotako rukhiyaymẽ',

# Rights
'right-read' => 'Sakamko paṛhaomẽ',
'right-edit' => 'Sakamko toṅge',
'right-createpage' => 'Sakamko benoamẽ (Okako do galmarao sakamko baṅkan)',
'right-createtalk' => 'Galmarao sakamko benaomẽ',
'right-createaccount' => 'Nãwã beoharićaḱ ekaunṭ tearmẽ',
'right-move' => 'Sakamko ocogmẽ',
'right-move-subpages' => 'Sakam saõte kạtic sakamko ocogmẽ',
'right-movefile' => 'Rẽtko ocogmẽ',
'right-upload' => 'Rẽtko rakabmẽ',
'right-delete' => 'Sakamko get giḍiymẽ',

# Special:Log/newusers
'newuserlogpage' => 'Laṛcaṛićaḱ tear cạbi',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'noa sakam joṛao',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1 bodol bodolko}}',
'recentchanges' => 'Nãwã bo̠do̠lko',
'recentchanges-legend' => 'Nahaḱ bodol teaḱko',
'recentchanges-summary' => 'Noa sakamre wiki reaḱ joto khon nãwã bodolko paṅjaṅjaymẽ.',
'recentchanges-feed-description' => 'Noa feedre wiki reaḱ joto khon nãwã bodolko paṅjaymẽ',
'recentchanges-label-newpage' => 'Noa sompadon do nãwã mint́ṭen sakame tearkeda',
'recentchanges-label-minor' => 'Noado hudiń mạchi sompadonkana',
'recentchanges-label-bot' => 'Noa sompadon do bot darate purauena',
'recentchanges-label-unpatrolled' => 'Noa sompadon do ńit́ hạbić baṅ ńel ńamakana',
'rcnote' => "Latar reaḱ {{PLURAL:$2 dinre '''$2''' dinre}} hoyena {{PLURAL:$1 '''1''' '''$1'''}}gan bodol latare uduḱena ((okare nitaḱ okte ar tạrikh do $5, $4).",
'rcnotefrom' => '$2 habić bodolak ko do latare ńeloḱkana',
'rclistfrom' => 'Nãwã  bodolko uduḱme $1 khon ehoṕkate',
'rcshowhideminor' => '$1 kaṭic culuń tońge',
'rcshowhidebots' => ' boṭko $1',
'rcshowhideliu' => 'Beoharićaḱ boloḱ $1',
'rcshowhideanons' => '$1 Nũtum bańa bebohariḱ',
'rcshowhidepatr' => '$1 Biḍạen sompadonko',
'rcshowhidemine' => '$1 ińaḱ tońge',
'rclinks' => '$2 din lahare $1 bodol unuduḱme <br />$3',
'diff' => 'Judạ',
'hist' => 'Jạr',
'hide' => 'Danaṅ',
'show' => 'Udugme',
'minoreditletter' => 'm',
'newpageletter' => 'N',
'boteditletter' => 'b',
'rc-enhanced-expand' => 'Purạote uduḱ',
'rc-enhanced-hide' => 'Purạo cuku',

# Recent changes linked
'recentchangeslinked' => 'Sãotenaḱ bodolko',
'recentchangeslinked-toolbox' => 'Noṛjoṛ palaṭko',
'recentchangeslinked-title' => 'Bodolaḱko do "$1" sãote joṛao geya',
'recentchangeslinked-summary' => "Noa do ona tạlika kana oka do nebetarge bodol hoyakan oka do asokayte hatao akan sakam khon.

[[Special:Watchlist|your watchlist]] renaḱ sakamko do '''bold''' .",
'recentchangeslinked-page' => 'sakạm ńutum',
'recentchangeslinked-to' => 'Joṛaoaḱ sakamre ńel ocoyme emaḱ sakam bạgi katet',

# Upload
'upload' => 'Fael aploḍme',
'uploadbtn' => 'Rẽt rakabmẽ',
'uploadlogpage' => 'Chạbi do uthạome',
'filename' => 'Rẽt ńutum',
'filedesc' => 'Guṭ katha',
'fileuploadsummary' => 'Guṭ katha',
'savefile' => 'Rẽt rukhiyaymẽ',
'uploadedimage' => '"[[$1]]" rakaṕ huyena',
'upload-description' => 'Rẽt reaḱ jạṛ',
'watchthisupload' => 'Noa rẽt ńelmẽ',

'upload-file-error' => 'Bhitri reaḱ bhul',

'license' => 'Laisence benao',
'license-header' => 'Laisense benao',

# Special:ListFiles
'imgfile' => 'Rẽt',
'listfiles' => 'Rẽt reaḱ tạlika',
'listfiles_date' => 'Tạrikh',
'listfiles_name' => 'Ńutum',
'listfiles_user' => 'Beoharić, Laṛcaṛic',

# File description page
'file-anchor-link' => 'Re̕t',
'filehist' => 'Fael renaḱ Jạṛ',
'filehist-help' => 'date re click me/somóy re click me fail reak obostha nel lagit',
'filehist-deleteall' => 'Joto get giḍi',
'filehist-deleteone' => 'Get giḍi',
'filehist-revert' => 'Lahaleka',
'filehist-current' => 'Nitaḱ',
'filehist-datetime' => '̣Tạrikh/So̠mo̠y',
'filehist-thumb' => 'Ṭip',
'filehist-thumbtext' => '$1 lekan thambnail varson',
'filehist-user' => 'Laṛcaṛić',
'filehist-dimensions' => 'Maṕ',
'filehist-comment' => 'Roṛ',
'imagelinks' => 'Fael bebohar',
'linkstoimage' => 'Latar reaḱ {{PLURAL:$1 sakam $1 sakam}} khon noa rẽtre joṛao menaḱa:',
'nolinkstoimage' => 'Nonḍe do noa são joṛao sakam banuka',
'sharedupload-desc-here' => 'Noa rẽt do nonḍe khon-  $1 ar paseć eṭaḱaḱ porjekṭko beoharakana.
Noa reaḱ pasnao katha [$2 rẽt pasnao sakam] latare emena',

# Random page
'randompage' => 'Joṛao sakam',

# Statistics
'statistics' => 'Halot',
'statistics-pages' => 'Sakamko',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|baiṭ|baiṭ}}',
'nmembers' => '$1 {{PLURAL:$1 Gaõtaren Gaõtarenko}}',
'prefixindex' => 'Sanam sakam re joṛao menaḱ',
'shortpages' => 'Huḍiń sakamko',
'longpages' => 'Jiliń sakamko',
'listusers' => 'beoharićaḱ tạlika',
'usercreated' => '{{JẠT: $3 | benawakan}} $1 tarikre $2 okte',
'newpages' => 'Nãwa Patako',
'newpages-username' => 'Beoharićaḱ ńutum:',
'ancientpages' => 'Mare sakamko',
'move' => 'Ocoḱme, Kulme',
'movethispage' => 'Noa sakam ocogmẽ',
'pager-newer-n' => '{{PLURAL:$1 nãwaw aroyen 1ṭen nãwã aroyen $1ṭen}}',
'pager-older-n' => '{{PLURAL:$1 arhõ mare 1ṭen arhõ mare $1ṭen}}',

# Book sources
'booksources' => 'Puthi ńamoḱ ṭhại/jayga',
'booksources-search-legend' => 'Puthi reak ṭhai sendrayme',
'booksources-go' => 'Calaḱme',

# Special:Log
'log' => 'Cạbiko',

# Special:AllPages
'allpages' => 'joto sakam',
'alphaindexline' => '$1 hạbić $2',
'allarticles' => 'Sanam sakam',
'allpagesprev' => 'Tayom sećaḱ',
'allpagesnext' => 'Laha seć',
'allpagessubmit' => 'Calaḱme',

# Special:Categories
'categories' => 'rokom sokom',

# Special:LinkSearch
'linksearch-line' => '$2 khon $1 re joṛao hoeakana',

# Special:ListUsers
'listusers-submit' => 'Udugmẽ',
'listusers-blocked' => '(Esetgea)',

# Special:ListGroupRights
'listgrouprights-group' => 'Gaõta',
'listgrouprights-rights' => 'Ạidạriko',
'listgrouprights-helppage' => 'Goṛo:Gaõta ạidạri',
'listgrouprights-members' => 'Saõtenkoaḱ tạlika',
'listgrouprights-addgroup-all' => 'Joto gaõtare ko soṅgekom',
'listgrouprights-removegroup-all' => 'Joto gaõtaren ko ocoḱgiḍikom',

# Email user
'emailuser' => 'Nui beoharić e-mail emayme',
'emailpage' => 'E-mail beoharić',
'noemailtitle' => 'E-mail ṭhikạna do banuḱa',
'emailusername' => 'Beoharićaḱ ńutum:',
'emailusernamesubmit' => 'Em',
'emailfrom' => 'Kulić:',
'emailto' => 'Ńamić:',
'emailmessage' => 'Mesag',
'emailsend' => 'Kulmẽ',

# Watchlist
'watchlist' => "Inak' n'el ko",
'mywatchlist' => 'Iñak jagarna tạlikạ',
'watchlistfor2' => '$1 ($2) lạ̣gitte',
'watch' => 'Ńelme',
'unwatch' => "bang nelok' a",
'watchlist-details' => 'Baṅ purạo tạlikare {{PLURAL:$1ṭen sakam $1 ṭen sakam}} menaḱa (roṛ sakamko lekhare baṅ sapkate)',
'wlshowlast' => 'Mucạtet́ udukmẽ $1 baje $2 maha $3',
'watchlist-options' => 'Ńelok tạlika reak sonketko',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'Ńeloḱ kana...',

'changed' => 'Bodolena',

# Delete
'deletepage' => 'Sakam get giḍikam',
'delete-legend' => 'Get giḍi',
'actioncomplete' => 'kami Chabae-ena',
'actionfailed' => 'Kami bang hoe-lena',
'dellogpage' => 'Mãrao log',

# Rollback
'rollbacklink' => 'Ghurlạo ạcur',

# Protect
'protectlogpage' => 'Rukhiyạy tala cạbi',
'protectedarticle' => 'Rukhiyạgeya "[[$1]]"',
'protectcomment' => 'karon',
'protectexpiry' => 'Cabaḱ',

# Restrictions (nouns)
'restriction-edit' => 'Toṅge',
'restriction-move' => 'Ocoḱmẽ, Kulmẽ',
'restriction-create' => 'Tearmẽ, Benaomẽ',

# Undelete
'undeletelink' => 'Ńel/doho ruạṛ',
'undeleteviewlink' => 'Ńel',

# Namespace form on various pages
'namespace' => 'Ńutum reaḱ ṭhai',
'invert' => 'Seć bachao',
'blanknamespace' => 'Mukhiạ̣',

# Contributions
'contributions' => 'Beharićaḱ Kạmiko',
'contributions-title' => '$1 Beoharićaḱ kạmiko',
'mycontris' => 'Ińaḱ kạmiko',
'contribsub2' => '$1 ($2) lạgitte',
'uctop' => '(coṭ utạr)',
'month' => 'Cando khon (ar etohopreaḱ)',
'year' => "Nia serma reak' pahil khoch'",

'sp-contributions-newbies' => 'Nãwã ekaunṭ lạgit kạmiko uduḱme',
'sp-contributions-blocklog' => 'Tala eset',
'sp-contributions-uploads' => 'Rakaṕme',
'sp-contributions-logs' => 'Tala',
'sp-contributions-talk' => 'Roṛ',
'sp-contributions-search' => 'Kạmiko emoḱ lạgitte sendrayme',
'sp-contributions-username' => 'IP ṭhikạna se laṛcaṛićaḱ n̕utum',
'sp-contributions-toponly' => 'Khạli nahaḱ nãwã aroyen joṛao kamiko udukme',
'sp-contributions-submit' => 'Sendra',

# What links here
'whatlinkshere' => 'Cet́ link ko no̠nḍe do',
'whatlinkshere-title' => 'Oka sakam ko do "$1"-re joṛao menaḱa',
'whatlinkshere-page' => 'Sakam',
'linkshere' => "Latar reaḱ sakamko do '''[[:$1]]''' sakamre joṛao menaḱa:",
'nolinkshere' => "Jahan sakam khon '''[[:$1]]''' sakamre joṛao bạnuḱa",
'isredirect' => 'Bań sojhe sakam',
'istemplate' => 'Ar mit́ teć sãote joṛao',
'isimage' => 'Ret joṛao',
'whatlinkshere-prev' => '{{PLURAL:$1 Laha reaḱ Laha reaḱ$1ṭen}}',
'whatlinkshere-next' => '{{PLURAL:$1 |Laha renaḱ | Laha renaḱko $1}}',
'whatlinkshere-links' => 'Joṛaoko',
'whatlinkshere-hideredirs' => '$1 acurgeya',
'whatlinkshere-hidetrans' => '$1 ṭarnskuleson uduḱme',
'whatlinkshere-hidelinks' => '$1 joṛao',
'whatlinkshere-hideimages' => '$1 Chubi joṛaoko',
'whatlinkshere-filters' => 'Sapha',

# Block/unblock
'block' => 'Beoharić esedem',
'blockip' => 'Beoharić esedem',
'blockip-title' => 'Beoharić esedem',
'blockip-legend' => 'Beoharić esedem',
'ipboptions' => '2 Ghonṭa : 2 hours, 1 maha:1 day, 3 maha : 3 days,1 hapta :1 week, 2 hapta : 2 weeks, 1 cando :1 month, 3 cando : 3 months,6 cando :6 months,  1 serma :1 year,  Aemamaha : infinite',
'ipblocklist' => 'Beoharic esetgeyay',
'ipblocklist-submit' => 'Sendra',
'emailblock' => 'E-mail do esetgea',
'blocklink' => 'Eset́',
'unblocklink' => 'bań block',
'change-blocklink' => 'block judạ',
'contribslink' => 'em daṛeaḱ',
'emaillink' => 'E-mail kulmẽ',
'blocklogpage' => 'Tala eset',
'blocklogentry' => 'Eset [[$1]] sãote cabaḱ okte oka do $2 $3',
'block-log-flags-nocreate' => 'Ekaunṭ benao do bondogeya',
'block-log-flags-noemail' => 'E-mail do esetgea',
'block-log-flags-hiddenname' => 'Beoharićaḱ ńutum do ukugea',

# Move page
'movepagebtn' => 'Sakam ocogmẽ, Sakam kulmẽ',
'pagemovedsub' => 'Ocogoḱ do hoena',
'movelogpage' => 'Tala cạbi ocoḱme',
'revertmove' => 'ruạr agu',

# Export
'export' => 'Aguyen sakamko',
'export-addcat' => 'Joṛaomẽ',
'export-addns' => 'Joṛaomẽ',

# Namespace 8 related
'allmessagesname' => 'Ńutum',
'allmessagesdefault' => 'Bań bhul mesag ol',
'allmessages-filter-all' => 'Sanamaḱ',
'allmessages-filter-submit' => 'Calaḱmẽ',

# Thumbnails
'thumbnail-more' => 'Lạṭui mẽ',
'thumbnail_error' => 'Benawakan unuduḱ kạṭuṕ do baṅ ṭhika: $1',

# Special:Import
'import-upload-filename' => 'Rẽt ńutum',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Amaḱ́ bebo̠harić sakam',
'tooltip-pt-mytalk' => 'Amaḱ katha ro̠ṛrenaḱ́ sakam',
'tooltip-pt-preferences' => 'Amaḱ pạsindko',
'tooltip-pt-watchlist' => 'Sakam tạlika okaṭak̕katet́ am do nãwã aroy lạgitem ńeleḱkan',
'tooltip-pt-mycontris' => 'Amaḱ kạmi reaḱ tạlika',
'tooltip-pt-login' => 'Am do log in lagit́ metao am kana; menkhan noa do jarur bań kana',
'tooltip-pt-logout' => 'O̠nḍo̠ńme',
'tooltip-ca-talk' => 'Galmãrao bhitri renaḱ sakam lạgit́',
'tooltip-ca-edit' => 'Noa sakam em edit daṛeaḱ. Daya kateć save laha re preview batton bebohar me.',
'tooltip-ca-addsection' => 'Nãwã sekson sạrdi',
'tooltip-ca-viewsource' => 'Noa sakam do poṭom gea
Ona te source em ńel daṛeaḱ',
'tooltip-ca-history' => 'Noa sakam renaḱ calao parom ńel ruạṛ',
'tooltip-ca-protect' => 'ñia sakam bachaome',
'tooltip-ca-delete' => 'nia sakam muchau me',
'tooltip-ca-move' => 'Noa sakam kulme',
'tooltip-ca-watch' => 'Noa sakam do amaḱ ńelok tạlikare joṛaome',
'tooltip-ca-unwatch' => 'Amaḱ ńeloḱ tạlika khon noa sakam bagiyam',
'tooltip-search' => 'Sendra {{Saiṭñitum}}',
'tooltip-search-go' => 'Mitṭen sakamre calaḱme one okare noa ńutum menaḱa',
'tooltip-search-fulltext' => 'Noa ol ńam lạgit sakamko ńelme',
'tooltip-p-logo' => 'Mukhiạ sakamre calaḱme',
'tooltip-n-mainpage' => 'Mukhiạ sakamre calaḱme',
'tooltip-n-mainpage-description' => 'Mukhiạ sakamre calaḱme',
'tooltip-n-portal' => 'Niạ pro̠je̠ḱ́ṭreaḱ Biso̠yko, Cet́em ceka daṛia,Okare̠ sendra ñamoḱ́a',
'tooltip-n-currentevents' => 'Nitaḱ events re jos hudis ńãm me',
'tooltip-n-recentchanges' => 'Uiki nãhaḱ palaṭrenaḱ́ tạlikạ',
'tooltip-n-randompage' => 'Ãr hõ sakam ko agui mẽ',
'tooltip-n-help' => 'Sendra ñamreaḱ jayga',
'tooltip-t-whatlinkshere' => 'Sanam wiki sakam renaḱ list ar link do nonde',
'tooltip-t-recentchangeslinked' => 'Noa sakam re nitaḱ bodol akan sakam renaḱ linked',
'tooltip-feed-atom' => 'Noa sakam lạgit́ atom jomaḱ',
'tooltip-t-contributions' => 'Beoharićak kami reaḱ tạ̣lika',
'tooltip-t-emailuser' => 'Nui beoharić mitṭen e-mail kulayme',
'tooltip-t-upload' => 'Failko aploḍ̣me',
'tooltip-t-specialpages' => 'Jạruṛ patakureaḱ tạlikạ',
'tooltip-t-print' => 'Printoḱ lekan sakam',
'tooltip-t-permalink' => 'Terejuge joṛaokam ñel sakam',
'tooltip-ca-nstab-main' => 'Bahal sakam ńel me',
'tooltip-ca-nstab-user' => 'Beoharićaḱ sakam uduḱme',
'tooltip-ca-nstab-special' => 'Noa do nij/bises sakam kana, amem menle rehõ bam joṛao dareaḱa',
'tooltip-ca-nstab-project' => "project page nel' me",
'tooltip-ca-nstab-image' => 'Fael sakam ńel',
'tooltip-ca-nstab-template' => 'Forom uduḱme',
'tooltip-ca-nstab-help' => 'Goṛo sakam ńelmẽ',
'tooltip-ca-nstab-category' => 'Rokom sokom sakamko udukme',
'tooltip-minoredit' => 'Noa do huḍiń joṛao lekate lekhay me',
'tooltip-save' => 'Bodolaḱko rukhiyayme',
'tooltip-preview' => 'Amaḱ bodolaḱ uduḱme, noa beoharme ạuri rukhiyayre',
'tooltip-diff' => 'Uduḱme okaṭaḱ onolem bodolakada',
'tooltip-compareselectedversions' => 'Noa barea sakam talareaḱ bepaneyaḱ nãwã aróme',
'tooltip-watch' => 'Amaḱ ńeloḱ sakamre noa do dohoyme',
'tooltip-rollback' => '"Ghurlạ ạcur" noa sakam taṛam ruạṛ ńel sapha ona do amaḱ mũcạt́ mit́ dhom click re',
'tooltip-undo' => 'Noa joṛao kạmire ulṭao "bạgiyaḱme" ar ńeloḱ lekate noa joṛao jhicme. Noa do am guḍ karon joṛaoe ektiyariye emama.',
'tooltip-preferences-save' => 'Pạsindko rukhiyaymẽ',
'tooltip-summary' => 'Khaṭote guṭ katha bhoraome',

# Attribution
'others' => 'Eṭagaḱko',

# Info page
'pageinfo-header-edits' => 'Toṅgeko',
'pageinfo-watchers' => 'Ńeńelkoaḱ nombor',

# Browsing diffs
'previousdiff' => "mareak' kamiko",
'nextdiff' => 'Nãwã joṛao',

# Media information
'file-info-size' => '$1 x $2 pixels, file size: $3, MIME type: $4',
'file-nohires' => 'Aema resulation nondḍe banuḱa',
'svg-long-desc' => 'SVG rẽt, normalte $1 x $2 pixels, rẽt sayej: $3',
'show-big-image' => 'Purạo resulation',

# Special:NewFiles
'ilsubmit' => 'Sendra',

# Bad image list
'bad_image_list' => 'Format do latar re leka',

# Metadata
'metadata' => 'Meṭa khobor',
'metadata-help' => 'Noa rẹt redo bạṛti kathako menaḱa, paseć noa do ḍejiṭal kemera se skenar bebohar hoy kate ḍijiṭal benao. Judi noa ret noa reaḱ asolak khon nãwã aro lenkhan, paseć sanamaḱko thoṛa bań sodoroḱa noa retredo.',
'metadata-fields' => 'Noa ciṭhire menaḱ photo reaḱ metadata jayga ṭalika do photo reaḱ sakamreye uduga, tinre ona metadata tibil do cabaḱa.
Eṭagaḱ sanamko do ońkage eset tahẽna.
Benao, Teyar
Moḍel
tạrik okte asolak
hire okte
f nombor
isospeeddratings
jeleń',

# Exif tags
'exif-imagewidth' => 'Ganḍe',
'exif-imagelength' => 'Usul',
'exif-datetime' => 'Rẽt bodol reaḱ tạrikh ar okte',
'exif-artist' => 'Onoliạ',

# External editor support
'edit-externally' => 'Noa rẽt tońge joṛao lạgitte bahre reaḱ koejoń  beoharme',
'edit-externally-help' => '(Nonḍe ńelme [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] bạṛtite baḍay lạgit)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'Sanam, sanamak, sanamko',
'namespacesall' => 'sanam',
'monthsall' => 'Sanamak',

# Watchlist editing tools
'watchlisttools-view' => 'Jońgṛao bodolaḱko ńel',
'watchlisttools-edit' => 'Ńelok tạlika ńel ar joṛao',
'watchlisttools-raw' => 'Baṇ purạo akan ńelok tạlika purạomẽ',

# Core parser functions
'duplicate-defaultsort' => "'''Sontoroḱmẽ:''' ḍifolṭ sajao reaḱ cạbi: $2 lahare ḍifolṭ sajao reaḱ sakam: ''$1'' e bae luturaḱ kana.",

# Special:SpecialPages
'specialpages' => 'Jạruṛ patako',

# External image whitelist
'external_image_whitelist' => '#Noa sakam do cet leka menaḱa oṅkage dohoemẽ
#Sanam okte re jạhiren kuṭrạ latar re (khạli hạtiń //talare) bạisạomẽ
#Noako do bahre reaḱ (hotlinked) chubi reaḱ URL saõte milạo hoyoḱa
#Okako milạḱa, onako do chubi lekate udugoḱa, baṅkhan do khali chubi joṛao udugoḱa
#Noa layen reaḱ ehoṕre # menaḱa ona layenko menko hisapte beohar hoyoḱka
#Noa do kas-baṅ rimjhạoaḱge
#Noa dag cetanre regex kuṭrạ bạsạomẽ. Noa layen cetleka menaḱa oṅkage dohoemẽ</pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tag]] saphay:',

);
